---------------------------------------------------------------------------
-- This VHDL file was developed by Daniel Llamocca (2013).  It may be
-- freely copied and/or distributed at no cost.  Any persons using this
-- file for any purpose do so at their own risk, and are responsible for
-- the results of such use.  Daniel Llamocca does not guarantee that
-- this file is complete, correct, or fit for any particular purpose.
-- NO WARRANTY OF ANY KIND IS EXPRESSED OR IMPLIED.  This notice must
-- accompany any copy of this file.
--------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

-- This circuit detects whether an N-bit signal is made of ones or zeros.
entity zeros_ones_detector is
	generic (N: INTEGER:= 8);
		port ( in_data: in std_logic_vector(N-1 downto 0);
				 all_zeros, all_ones: out std_logic);
end zeros_ones_detector;

architecture behaviour of zeros_ones_detector is
		
begin

	process(in_data)
		variable result_and, result_or: std_logic;
	begin
		result_and:= '1'; result_or := '0';
		for i in in_data'range loop -- 'range: iterates through all the bits in 'in_data'.
			result_and:= result_and and in_data(i);
			result_or:= result_or or in_data(i);
		end loop;
	
		all_zeros <= not(result_or);
		all_ones <= result_and;
	end process;
	
end behaviour;
